@@ -2,11 +2,11 @@ package db_common
 
 import (
 	"github.com/jackc/pgx/v5/pgconn"
-	"github.com/turbot/steampipe/pkg/utils"
+	"github.com/turbot/steampipe/pkg/db/sslio"
 )
 
 func AddRootCertToConfig(config *pgconn.Config, certLocation string) error {
-	rootCert, err := utils.ParseCertificateInLocation(certLocation)
+	rootCert, err := sslio.ParseCertificateInLocation(certLocation)
 	if err != nil {
 		return err
 	}
