@@ -122,7 +122,7 @@ func StartServices(ctx context.Context, listenAddresses []string, port int, invo
 		}
 
 		// start plugin manager if needed
-		pluginManager, pluginManagerState, err := ensurePluginManager()
+		pluginManager, pluginManagerState, err := ensurePluginManager(ctx)
 		res.PluginManagerState = pluginManagerState
 		res.PluginManager = pluginManager
 		if err != nil {
@@ -136,7 +136,7 @@ func StartServices(ctx context.Context, listenAddresses []string, port int, invo
 	return res
 }
 
-func ensurePluginManager() (*pluginmanager.PluginManagerClient, *pluginmanager.State, error) {
+func ensurePluginManager(ctx context.Context) (*pluginmanager.PluginManagerClient, *pluginmanager.State, error) {
 	// start the plugin manager if needed
 	state, err := pluginmanager.LoadState()
 	if err != nil {
@@ -208,7 +208,6 @@ func postServiceStart(ctx context.Context, res *StartResult) error {
 		return sperr.WrapWithMessage(err, "failed to migrate db public schema")
 	}
 
-	statushooks.SetStatus(ctx, "Call initial refresh connections")
 	return nil
 }
 
@@ -460,6 +459,14 @@ func createCmd(ctx context.Context, port int, listenAddresses []string) *exec.Cm
 		// Data Directory
 		"-D", filepaths.GetDataLocation())
 
+	if sslpassword := viper.GetString(constants.ArgDatabaseSSLPassword); sslpassword != "" {
+		postgresCmd.Args = append(
+			postgresCmd.Args,
+			"-c", fmt.Sprintf("ssl_passphrase_command_supports_reload=%s", "true"),
+			"-c", fmt.Sprintf("ssl_passphrase_command=%s", "echo "+sslpassword),
+		)
+	}
+
 	postgresCmd.Env = append(os.Environ(), fmt.Sprintf("STEAMPIPE_INSTALL_DIR=%s", filepaths.SteampipeDir))
 
 	//  Check if the /etc/ssl directory exist in os
