@@ -1,7 +1,7 @@
 package modinstaller
 
 import (
-	"github.com/Masterminds/semver"
+	"github.com/Masterminds/semver/v3"
 	"github.com/go-git/go-git/v5/plumbing"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/turbot/steampipe/pkg/versionhelpers"
@@ -43,7 +43,7 @@ func (r *ResolvedModRef) setGitReference() {
 	r.GitReference = plumbing.NewTagReferenceName(r.Version.Original())
 }
 
-// FullName returns name in the format <dependency name>@v<dependencyVersion>
-func (r *ResolvedModRef) FullName() string {
-	return modconfig.ModVersionFullName(r.Name, r.Version)
+// DependencyPath returns name in the format <dependency name>@v<dependencyVersion>
+func (r *ResolvedModRef) DependencyPath() string {
+	return modconfig.BuildModDependencyPath(r.Name, r.Version)
 }
