@@ -10,19 +10,21 @@ import (
 	"github.com/hashicorp/go-hclog"
 	"github.com/hashicorp/go-plugin"
 	"github.com/turbot/steampipe-plugin-sdk/v5/logging"
+	"github.com/turbot/steampipe-plugin-sdk/v5/sperr"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/filepaths"
+	"github.com/turbot/steampipe/pkg/pluginmanager_service/grpc"
 	pb "github.com/turbot/steampipe/pkg/pluginmanager_service/grpc/proto"
 	pluginshared "github.com/turbot/steampipe/pkg/pluginmanager_service/grpc/shared"
 )
 
 // StartNewInstance loads the plugin manager state, stops any previous instance and instantiates a new plugin manager
-func StartNewInstance(steampipeExecutablePath string) error {
+func StartNewInstance(steampipeExecutablePath string) (*State, error) {
 	// try to load the plugin manager state
-	state, err := LoadPluginManagerState()
+	state, err := LoadState()
 	if err != nil {
 		log.Printf("[WARN] plugin manager StartNewInstance() - load state failed: %s", err)
-		return err
+		return nil, err
 	}
 
 	if state.Running {
@@ -30,7 +32,7 @@ func StartNewInstance(steampipeExecutablePath string) error {
 		// stop the current instance
 		if err := stop(state); err != nil {
 			log.Printf("[WARN] failed to stop previous instance of plugin manager: %s", err)
-			return err
+			return nil, err
 		}
 	}
 	return start(steampipeExecutablePath)
@@ -40,7 +42,7 @@ func StartNewInstance(steampipeExecutablePath string) error {
 // we need to be provided with the exe path as we have no way of knowing where the steampipe exe it
 // when the plugin mananager is first started by steampipe, we derive the exe path from the running process and
 // store it in the plugin manager state file - then if the fdw needs to start the plugin manager it knows how to
-func start(steampipeExecutablePath string) error {
+func start(steampipeExecutablePath string) (*State, error) {
 	// note: we assume the install dir has been assigned to file_paths.SteampipeDir
 	// - this is done both by the FDW and Steampipe
 	pluginManagerCmd := exec.Command(steampipeExecutablePath,
@@ -52,7 +54,7 @@ func start(steampipeExecutablePath string) error {
 	}
 
 	// discard logging from the plugin manager client (plugin manager logs will still flow through to the log file
-	// as this is set up in the pluginb manager)
+	// as this is set up in the plugin manager)
 	logger := logging.NewLogger(&hclog.LoggerOptions{Name: "plugin", Output: io.Discard})
 
 	// launch the plugin manager the plugin process
@@ -66,22 +68,29 @@ func start(steampipeExecutablePath string) error {
 
 	if _, err := client.Start(); err != nil {
 		log.Printf("[WARN] plugin manager start() failed to start GRPC client for plugin manager: %s", err)
-		return err
+		// attempt to retrieve error message encoded in the plugin stdout
+		err = sperr.WrapWithMessage(grpc.HandleStartFailure(err), "failed to start plugin manager")
+		return nil, err
 	}
 
 	// create a plugin manager state.
-	state := NewPluginManagerState(steampipeExecutablePath, client.ReattachConfig())
+	state := NewState(steampipeExecutablePath, client.ReattachConfig())
 
 	log.Printf("[TRACE] start: started plugin manager, pid %d", state.Pid)
 
 	// now save the state
-	return state.Save()
+	if err := state.Save(); err != nil {
+		return nil, err
+	}
+	return state, nil
 }
 
 // Stop loads the plugin manager state and if a running instance is found, stop it
 func Stop() error {
+	log.Println("[DEBUG] pluginmanager.Stop start")
+	defer log.Println("[DEBUG] pluginmanager.Stop end")
 	// try to load the plugin manager state
-	state, err := LoadPluginManagerState()
+	state, err := LoadState()
 	if err != nil {
 		return err
 	}
@@ -93,8 +102,10 @@ func Stop() error {
 }
 
 // stop the running plugin manager instance
-func stop(state *PluginManagerState) error {
-	log.Printf("[TRACE] plugin manager stop")
+func stop(state *State) error {
+	log.Println("[DEBUG] pluginmanager.stop start")
+	defer log.Println("[DEBUG] pluginmanager.stop end")
+
 	pluginManager, err := NewPluginManagerClient(state)
 	if err != nil {
 		return err
@@ -106,11 +117,13 @@ func stop(state *PluginManagerState) error {
 	if err != nil {
 		return err
 	}
+	log.Printf("[TRACE] pluginManager.Shutdown done")
 
 	// kill the underlying client
+	log.Printf("[TRACE] pluginManager.Shutdown killing raw client")
 	pluginManager.rawClient.Kill()
+	log.Printf("[TRACE] pluginManager.Shutdown killed raw client")
 
-	log.Printf("[TRACE] pluginManager state.kill")
 	// now kill the plugin manager
 	return state.kill()
 }
@@ -125,7 +138,7 @@ func GetPluginManager() (pluginshared.PluginManager, error) {
 // it then returns a plugin manager client
 func getPluginManager(startIfNeeded bool) (pluginshared.PluginManager, error) {
 	// try to load the plugin manager state
-	state, err := LoadPluginManagerState()
+	state, err := LoadState()
 	if err != nil {
 		log.Printf("[WARN] failed to load plugin manager state: %s", err.Error())
 		return nil, err
@@ -136,22 +149,23 @@ func getPluginManager(startIfNeeded bool) (pluginshared.PluginManager, error) {
 	if state.Executable == "" {
 		return nil, fmt.Errorf("plugin manager is not running and there is no state file")
 	}
-	// if the plugin manager is not running, it must have crashed/terminated
-	if !state.Running {
-		log.Printf("[TRACE] GetPluginManager called but plugin manager not running")
-		// is we are not already recursing, start the plugin manager then recurse back into this function
-		if startIfNeeded {
-			log.Printf("[TRACE] calling StartNewInstance()")
-			// start the plugin manager
-			if err := start(state.Executable); err != nil {
-				return nil, err
-			}
-			// recurse in, setting startIfNeeded to false to avoid further recursion on failure
-			return getPluginManager(false)
-		}
-		// not retrying - just fail
-		return nil, fmt.Errorf("plugin manager is not running")
+	if state.Running {
+		log.Printf("[TRACE] plugin manager is running - returning client")
+		return NewPluginManagerClient(state)
 	}
-	log.Printf("[TRACE] plugin manager is running - returning client")
-	return NewPluginManagerClient(state)
+
+	// if the plugin manager is not running, it must have crashed/terminated
+	log.Printf("[TRACE] GetPluginManager called but plugin manager not running")
+	// is we are not already recursing, start the plugin manager then recurse back into this function
+	if startIfNeeded {
+		log.Printf("[TRACE] calling StartNewInstance()")
+		// start the plugin manager
+		if _, err := start(state.Executable); err != nil {
+			return nil, err
+		}
+		// recurse in, setting startIfNeeded to false to avoid further recursion on failure
+		return getPluginManager(false)
+	}
+	// not retrying - just fail
+	return nil, fmt.Errorf("plugin manager is not running")
 }
