@@ -3,6 +3,8 @@ package modconfig
 import (
 	"fmt"
 	"strings"
+
+	"github.com/turbot/steampipe-plugin-sdk/v5/sperr"
 )
 
 type ParsedResourceName struct {
@@ -21,7 +23,7 @@ func ParseResourceName(fullName string) (res *ParsedResourceName, err error) {
 
 	switch len(parts) {
 	case 0:
-		err = fmt.Errorf("empty name passed to ParseResourceName")
+		err = sperr.New("empty name passed to ParseResourceName")
 	case 1:
 		res.Name = parts[0]
 	case 2:
@@ -32,10 +34,10 @@ func ParseResourceName(fullName string) (res *ParsedResourceName, err error) {
 		res.ItemType = parts[1]
 		res.Name = parts[2]
 	default:
-		err = fmt.Errorf("invalid name '%s' passed to ParseResourceName", fullName)
+		err = sperr.New("invalid name '%s' passed to ParseResourceName", fullName)
 	}
 	if !IsValidResourceItemType(res.ItemType) {
-		err = fmt.Errorf("invalid name '%s' passed to ParseResourceName", fullName)
+		err = sperr.New("invalid name '%s' passed to ParseResourceName", fullName)
 	}
 	return
 }
@@ -44,10 +46,11 @@ func (p *ParsedResourceName) ToResourceName() string {
 	return BuildModResourceName(p.ItemType, p.Name)
 }
 
-func (p *ParsedResourceName) ToFullName() string {
+func (p *ParsedResourceName) ToFullName() (string, error) {
 	return BuildFullResourceName(p.Mod, p.ItemType, p.Name)
 }
-func (p *ParsedResourceName) ToFullNameWithMod(mod string) string {
+
+func (p *ParsedResourceName) ToFullNameWithMod(mod string) (string, error) {
 	if p.Mod != "" {
 		return p.ToFullName()
 	}
@@ -56,9 +59,17 @@ func (p *ParsedResourceName) ToFullNameWithMod(mod string) string {
 
 // BuildFullResourceName generates a fully qualified name from the given components
 // e.g: aws_compliance.benchmark.cis_v150_1
-// TODO: validate argument are not empty strings [https://github.com/turbot/steampipe/issues/3601]
-func BuildFullResourceName(mod, blockType, name string) string {
-	return fmt.Sprintf("%s.%s.%s", mod, blockType, name)
+func BuildFullResourceName(mod, blockType, name string) (string, error) {
+	if mod == "" {
+		return "", sperr.New("mod name not provided")
+	}
+	if blockType == "" {
+		return "", sperr.New("block type not provided")
+	}
+	if name == "" {
+		return "", sperr.New("resource name not provided")
+	}
+	return fmt.Sprintf("%s.%s.%s", mod, blockType, name), nil
 }
 
 // UnqualifiedResourceName removes the mod prefix from the given name
