@@ -8,7 +8,8 @@ import (
 )
 
 type Plugin struct {
-	MemoryMaxMb *int `hcl:"memory_max_mb"`
+	MemoryMaxMb  *int `hcl:"memory_max_mb"`
+	StartTimeout *int `hcl:"start_timeout"`
 }
 
 // ConfigMap creates a config map that can be merged with viper
@@ -18,6 +19,11 @@ func (t *Plugin) ConfigMap() map[string]interface{} {
 	if t.MemoryMaxMb != nil {
 		res[constants.ArgMemoryMaxMbPlugin] = t.MemoryMaxMb
 	}
+	if t.StartTimeout != nil {
+		res[constants.ArgPluginStartTimeout] = t.StartTimeout
+	} else {
+		res[constants.ArgPluginStartTimeout] = constants.PluginStartTimeout.Seconds()
+	}
 
 	return res
 }
@@ -30,6 +36,9 @@ func (t *Plugin) Merge(otherOptions Options) {
 		if o.MemoryMaxMb != nil {
 			t.MemoryMaxMb = o.MemoryMaxMb
 		}
+		if o.StartTimeout != nil {
+			t.StartTimeout = o.StartTimeout
+		}
 	}
 }
 
@@ -43,6 +52,11 @@ func (t *Plugin) String() string {
 	} else {
 		str = append(str, fmt.Sprintf("  MemoryMaxMb: %d", *t.MemoryMaxMb))
 	}
+	if t.StartTimeout == nil {
+		str = append(str, "  PluginStartTimeout: nil")
+	} else {
+		str = append(str, fmt.Sprintf("  PluginStartTimeout: %d", *t.StartTimeout))
+	}
 
 	return strings.Join(str, "\n")
 }
